@@ -1,6 +1,6 @@
 package POEx::WorkerPool::Error::JobError;
 BEGIN {
-  $POEx::WorkerPool::Error::JobError::VERSION = '1.101040';
+  $POEx::WorkerPool::Error::JobError::VERSION = '1.101610';
 }
 
 #ABSTRACT: An error class indicating something failed with the job
@@ -29,7 +29,7 @@ POEx::WorkerPool::Error::JobError - An error class indicating something failed w
 
 =head1 VERSION
 
-version 1.101040
+version 1.101610
 
 =head1 DESCRIPTION
 
@@ -52,7 +52,7 @@ during execution of the previous step
 
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+  Nicholas R. Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
