@@ -1,6 +1,6 @@
 package POEx::WorkerPool::Role::Job;
 BEGIN {
-  $POEx::WorkerPool::Role::Job::VERSION = '1.101040';
+  $POEx::WorkerPool::Role::Job::VERSION = '1.101610';
 }
 
 #ABSTRACT: Provides a role for common job semantics
@@ -117,7 +117,7 @@ POEx::WorkerPool::Role::Job - Provides a role for common job semantics
 
 =head1 VERSION
 
-version 1.101040
+version 1.101610
 
 =head1 SYNOPSIS
 
@@ -196,7 +196,7 @@ exception class is JobError
 
 =head1 AUTHOR
 
-  Nicholas Perez <nperez@cpan.org>
+  Nicholas R. Perez <nperez@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
